import PolicyInterface from '../../interfaces/PolicyInterface.js';
import PolicyType from '../../enum/PolicyTypeEnum.js';
declare abstract class AbstractPolicy implements PolicyInterface {
    static readonly TYPE_BYTE_OFF = 0;
    static readonly TYPE_BYTE_LEN = 1;
    static readonly BODY_BYTE_OFF = 1;
    static readonly BODY_BYTE_MIN_LEN = 3;
    static readonly BODY_BYTE_MAX_LEN = 257;
    static readonly BINDING_BYTE_MIN_LEN = 8;
    static readonly BINDING_BYTE_MAX_LEN = 132;
    static readonly SIZE_OF_LENGTH_FIELD = 1;
    static readonly GMAC_BINDING_LEN = 8;
    readonly type: PolicyType;
    readonly binding: Uint8Array;
    static parse(buff: Uint8Array, useECDSABinding: boolean, type?: PolicyType): {
        policy: PolicyInterface;
        offset: number;
    };
    constructor(type: PolicyType, binding: Uint8Array);
    /**
     * Length of policy
     */
    getLength(): number | never;
    /**
     * Return the content of the policy
     */
    toBuffer(): Uint8Array | never;
    /**
     * Parses an ECDSA binding from a given buffer.
     *
     * @param {Uint8Array} buff - The buffer containing the ECDSA binding.
     * @returns {{ bindingLength: number; binding: Uint8Array }} - An object containing the binding length and the binding subarray.
     */
    static parseECDSABinding(buff: Uint8Array): {
        bindingLength: number;
        binding: Uint8Array;
    };
    /**
     * Parses a binding from a given buffer based on the specified binding type.
     *
     * @param {Uint8Array} buff - The buffer containing the binding.
     * @param {boolean} useEcdsaBinding - Flag indicating whether to use ECDSA binding.
     * @param {number} offset - The starting offset in the buffer.
     * @returns {{ binding: Uint8Array; newOffset: number }} - An object containing the binding and the new offset.
     */
    static parseBinding(buff: Uint8Array, useEcdsaBinding: boolean, offset: number): {
        binding: Uint8Array;
        newOffset: number;
    };
}
export default AbstractPolicy;
//# sourceMappingURL=AbstractPolicy.d.ts.map