/**
 * Read data from a seekable stream.
 * This is an abstraction for URLs with range queries and local file objects.
 * @param byteStart First byte to read. If negative, reads from the end. If absent, reads everything
 * @param byteEnd Index after last byte to read (exclusive)
 */
export type Chunker = (byteStart?: number, byteEnd?: number) => Promise<Uint8Array>;
/**
 * Type union for a variety of inputs.
 */
export type Source = {
    type: 'buffer';
    location: Uint8Array;
} | {
    type: 'chunker';
    location: Chunker;
} | {
    type: 'file-browser';
    location: Blob;
} | {
    type: 'remote';
    location: string;
} | {
    type: 'stream';
    location: ReadableStream<Uint8Array>;
};
/**
 * Creates a seekable object from a browser file object.
 * @param fileRef the browser file data
 */
export declare const fromBrowserFile: (fileRef: Blob) => Chunker;
export declare const fromBuffer: (source: Uint8Array) => Chunker;
export declare const fromString: (source: string) => Chunker;
export declare const fromUrl: (location: string) => Promise<Chunker>;
export declare const fromSource: ({ type, location }: Source) => Promise<Chunker>;
export declare function sourceToStream(source: Source): Promise<ReadableStream<Uint8Array>>;
export declare const fromDataSource: ({ type, location }: Source) => Promise<Chunker>;
export type DataSource = Source;
//# sourceMappingURL=seekable.d.ts.map