import { Binary } from '../binary.js';
import { type SymmetricCipher } from '../ciphers/symmetric-cipher-base.js';
import { type KeyAccess, type KeyAccessObject } from './key-access.js';
import { type Policy } from './policy.js';
import { type CryptoService, type DecryptResult, type EncryptResult } from '../crypto/declarations.js';
import { IntegrityAlgorithm } from '../tdf.js';
export type KeyInfo = {
    readonly unwrappedKeyBinary: Binary;
    readonly unwrappedKeyIvBinary: Binary;
};
export type Segment = {
    readonly hash: string;
    readonly segmentSize?: number;
    readonly encryptedSegmentSize?: number;
};
export type SplitType = 'split';
export type EncryptionInformation = {
    readonly type: SplitType;
    readonly keyAccess: KeyAccessObject[];
    readonly integrityInformation: {
        readonly rootSignature: {
            alg: IntegrityAlgorithm;
            sig: string;
        };
        segmentHashAlg?: IntegrityAlgorithm;
        segments: Segment[];
        segmentSizeDefault?: number;
        encryptedSegmentSizeDefault?: number;
    };
    readonly method: {
        readonly algorithm: string;
        isStreamable: boolean;
        readonly iv: string;
    };
    policy: string;
};
export declare class SplitKey {
    readonly cipher: SymmetricCipher;
    readonly cryptoService: CryptoService;
    keyAccess: KeyAccess[];
    constructor(cipher: SymmetricCipher);
    generateKey(): Promise<KeyInfo>;
    encrypt(contentBinary: Binary, keyBinary: Binary, ivBinaryOptional?: Binary): Promise<EncryptResult>;
    decrypt(content: Uint8Array, keyBinary: Binary): Promise<DecryptResult>;
    getKeyAccessObjects(policy: Policy, keyInfo: KeyInfo): Promise<KeyAccessObject[]>;
    generateIvBinary(): Promise<Binary>;
    write(policy: Policy, keyInfo: KeyInfo): Promise<EncryptionInformation>;
}
//# sourceMappingURL=encryption-information.d.ts.map