import { type CryptoService } from '../crypto/declarations.js';
export declare function bxor(b1: Uint8Array, b2: Uint8Array): Uint8Array;
/**
 * Spreads the data in `key` across `n` shares of the same size, using
 * secure random noise so that any n-1 subset of the keys contains no
 * information. This allows a user to store a key across multiple KAS servers.
 * @param key The data to split
 * @param n The number of entries to split across
 * @returns `n` entries of `length(key)` size
 */
export declare function keySplit(key: Uint8Array, n: number, cryptoService: CryptoService): Promise<Uint8Array[]>;
/**
 * Combines K secret shares, as generated from `keySplit`, into a single value.
 * Note this does no verfication!
 * @param splits the split values, aggregated from KASen
 * @returns the merged value.
 */
export declare function keyMerge(splits: Uint8Array[]): Uint8Array;
//# sourceMappingURL=keysplit.d.ts.map